package com.ruoyi.traceability.service;

import java.util.List;
import com.ruoyi.traceability.domain.ProDownrecord;

/**
 * 下料记录Service接口
 * 
 * @author wenjy
 * @date 2022-11-13
 */
public interface IProDownrecordService 
{
    /**
     * 查询下料记录
     * 
     * @param id 下料记录主键
     * @return 下料记录
     */
    public ProDownrecord selectProDownrecordById(Long id);

    /**
     * 查询下料记录列表
     * 
     * @param proDownrecord 下料记录
     * @return 下料记录集合
     */
    public List<ProDownrecord> selectProDownrecordList(ProDownrecord proDownrecord);

    /**
     * 新增下料记录
     * 
     * @param proDownrecord 下料记录
     * @return 结果
     */
    public int insertProDownrecord(ProDownrecord proDownrecord);

    /**
     * 修改下料记录
     * 
     * @param proDownrecord 下料记录
     * @return 结果
     */
    public int updateProDownrecord(ProDownrecord proDownrecord);

    /**
     * 批量删除下料记录
     * 
     * @param ids 需要删除的下料记录主键集合
     * @return 结果
     */
    public int deleteProDownrecordByIds(String ids);

    /**
     * 删除下料记录信息
     * 
     * @param id 下料记录主键
     * @return 结果
     */
    public int deleteProDownrecordById(Long id);
}
